@@ -1,13 +1,12 @@
 import pytest
 from barte import BarteClient
 
+
 @pytest.fixture
 def barte_client():
     """Fixture that provides a Barte client instance for testing"""
-    return BarteClient(
-        api_key="test_api_key_123",
-        environment="sandbox"
-    )
+    return BarteClient(api_key="test_api_key_123", environment="sandbox")
+
 
 @pytest.fixture
 def mock_response():
@@ -18,5 +17,5 @@ def mock_response():
         "created_at": "2024-03-20T10:00:00Z",
         "amount": 1000,
         "currency": "BRL",
-        "description": "Test charge"
-    } 
\ No newline at end of file
+        "description": "Test charge",
+    }
